@@ -1,2 +1,2 @@
 from . import mnist
-from . import cifar
+from . import resnet
